import { Host, h } from "@stencil/core";
/**
 * @slot heading - Content will be placed at the top of the data list.
 */
export class DataList {
    constructor() {
        /**
         * The size of the data list component.
         */
        this.size = "medium";
        /**
         * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
    }
    render() {
        const { el, heading, size, theme } = this;
        if (size === "small") {
            Array.from(el.children).forEach((child) => child.setAttribute("size", "small"));
        }
        return (h(Host, { key: 'c66609f65612dca067e70b5762d7eeb797dd2121', class: {
                "ic-data-list-small": size === "small",
                [`ic-theme-${theme}`]: theme !== "inherit",
            } }, h("div", { key: '685663251c565cb665c03e9bd39e1d5b2f7ef73b', class: "heading", id: "data-list-heading" }, h("slot", { key: 'e81970054a2053f05f6c0ef378e2509bb602da65', name: "heading" }, h("ic-typography", { key: '860b07bd25a11f7f6a938aab5cbae0c5802bea3e', variant: "h3" }, heading))), h("div", { key: 'c004429938c7c71ac70ee106486f75193cffc2ca', class: "divider" }), h("ul", { key: 'b9e010a5703ecaf75ce3b1cf396901b26618a34a', "aria-labelledby": "data-list-heading", class: "rows" }, h("slot", { key: '684b99425193c3a5e306b67e235b7d85e1802fce' }))));
    }
    static get is() { return "ic-data-list"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-data-list.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-data-list.css"]
        };
    }
    static get properties() {
        return {
            "heading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The title for the data list."
                },
                "getter": false,
                "setter": false,
                "attribute": "heading",
                "reflect": false
            },
            "size": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcSizesNoLarge",
                    "resolved": "\"medium\" | \"small\" | undefined",
                    "references": {
                        "IcSizesNoLarge": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcSizesNoLarge"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The size of the data list component."
                },
                "getter": false,
                "setter": false,
                "attribute": "size",
                "reflect": false,
                "defaultValue": "\"medium\""
            },
            "theme": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcThemeMode",
                    "resolved": "\"dark\" | \"inherit\" | \"light\" | undefined",
                    "references": {
                        "IcThemeMode": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcThemeMode"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Sets the theme color to the dark or light theme color. \"inherit\" will set the color based on the system settings or ic-theme component."
                },
                "getter": false,
                "setter": false,
                "attribute": "theme",
                "reflect": false,
                "defaultValue": "\"inherit\""
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=ic-data-list.js.map
