import { Host, h } from "@stencil/core";
import { IcInformationStatus, } from "../../utils/types";
import successIcon from "../../assets/success-icon.svg";
import { removeDisabledFalse, renderDynamicChildSlots, slotHasContent, } from "../../utils/helpers";
/**
 * @slot left-icon - Content will be placed to the left of the input.
 */
export class InputComponentContainer {
    constructor() {
        /**
         *  If `true`, the disabled state will be set.
         */
        this.disabled = false;
        /**
         *  If `true`, the input component container will fill the width of the container it is in.
         */
        this.fullWidth = false;
        /**
         *  If `true`, the input component container will allow for multiple lines.
         */
        this.multiLine = false;
        /**
         *  If `true`, the readonly state will be set.
         */
        this.readonly = false;
        /**
         * The size of the input component container component.
         */
        this.size = "medium";
        /**
         *  If `true`, the validation will display inline.
         */
        this.validationInline = false;
        /**
         * The validation status of the input component container - e.g. 'error' | 'warning' | 'success'.
         */
        this.validationStatus = "";
    }
    watchDisabledHandler() {
        removeDisabledFalse(this.disabled, this.el);
    }
    componentWillLoad() {
        removeDisabledFalse(this.disabled, this.el);
    }
    componentDidLoad() {
        this.hostMutationObserver = new MutationObserver((mutationList) => renderDynamicChildSlots(mutationList, "left-icon", this));
        this.hostMutationObserver.observe(this.el, { childList: true });
    }
    render() {
        const { size, validationStatus, disabled, readonly, multiLine, fullWidth, validationInline, } = this;
        return (h(Host, { key: 'c33ebfd9dd18101fb9161259538e8e0046f77a3d', class: {
                [`ic-input-component-container-${size}`]: true,
                [`ic-input-component-container-${validationStatus}`]: validationStatus !== "" && !disabled && !readonly,
                "ic-input-component-container-disabled": !!disabled,
                "ic-input-component-container-readonly": !!readonly,
                "ic-input-component-container-multiline": !!multiLine,
                "ic-input-component-container-full-width": !!fullWidth,
            }, "aria-disabled": disabled ? "true" : null }, h("div", { key: 'a70f27a3235ac0edb9d9c5a18983ae3c02de2a48', class: "focus-indicator" }, slotHasContent(this.el, "left-icon") && (h("div", { key: 'aa0b233280382bd0e95a8ff932bf60a63603b7bf', class: "icon-container" }, h("slot", { key: 'ceb8ec9b420073ac2ecd5d6793ad4342ab9ebbdd', name: "left-icon" }))), h("slot", { key: '1850c6ed04510e678600c653a36e2114f982e561' }), validationInline &&
            validationStatus === IcInformationStatus.Success && (h("span", { key: '58d228c595577c1cc9a0fe2b10538cc3efff53ab', class: "inline-success", innerHTML: successIcon })))));
    }
    static get is() { return "ic-input-component-container"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-input-component-container.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-input-component-container.css"]
        };
    }
    static get properties() {
        return {
            "disabled": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the disabled state will be set."
                },
                "getter": false,
                "setter": false,
                "attribute": "disabled",
                "reflect": false,
                "defaultValue": "false"
            },
            "fullWidth": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the input component container will fill the width of the container it is in."
                },
                "getter": false,
                "setter": false,
                "attribute": "full-width",
                "reflect": false,
                "defaultValue": "false"
            },
            "multiLine": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the input component container will allow for multiple lines."
                },
                "getter": false,
                "setter": false,
                "attribute": "multi-line",
                "reflect": false,
                "defaultValue": "false"
            },
            "readonly": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the readonly state will be set."
                },
                "getter": false,
                "setter": false,
                "attribute": "readonly",
                "reflect": false,
                "defaultValue": "false"
            },
            "size": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcSizes",
                    "resolved": "\"large\" | \"medium\" | \"small\" | undefined",
                    "references": {
                        "IcSizes": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcSizes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The size of the input component container component."
                },
                "getter": false,
                "setter": false,
                "attribute": "size",
                "reflect": false,
                "defaultValue": "\"medium\""
            },
            "validationInline": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "If `true`, the validation will display inline."
                },
                "getter": false,
                "setter": false,
                "attribute": "validation-inline",
                "reflect": false,
                "defaultValue": "false"
            },
            "validationStatus": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcInformationStatusOrEmpty",
                    "resolved": "\"\" | \"error\" | \"success\" | \"warning\" | undefined",
                    "references": {
                        "IcInformationStatusOrEmpty": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcInformationStatusOrEmpty"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The validation status of the input component container - e.g. 'error' | 'warning' | 'success'."
                },
                "getter": false,
                "setter": false,
                "attribute": "validation-status",
                "reflect": false,
                "defaultValue": "\"\""
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "disabled",
                "methodName": "watchDisabledHandler"
            }];
    }
}
//# sourceMappingURL=ic-input-component-container.js.map
