import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as chevronIcon } from './chevron-icon.js';
import { i as isSlotUsed, m as getSlotElements, l as isPropDefined } from './helpers.js';
import { d as defineCustomElement$1 } from './ic-link2.js';

const backIcon = `<svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M20 11H7.83L13.42 5.41L12 4L4 12L12 20L13.41 18.59L7.83 13H20V11Z" fill="currentColor"/>
</svg>
`;

const icBreadcrumbCss = ":host{display:block;margin:var(--ic-space-xs) var(--ic-space-xs) var(--ic-space-xs) 0}:host .breadcrumb{display:flex;align-items:center;white-space:nowrap;gap:var(--ic-space-xs);min-height:var(--ic-space-lg)}:host .chevron{width:var(--ic-space-lg);height:var(--ic-space-lg)}:host .chevron svg,:host(.ic-breadcrumb-monochrome) .chevron svg{color:var(--ic-breadcrumb-icon-chevron)}:host(:first-child) .chevron{display:none}.back-icon svg{color:var(--ic-breadcrumb-icon)}:host(.ic-breadcrumb-monochrome) .back-icon svg{color:var(--ic-breadcrumb-icon-monochrome)}:host(.ic-breadcrumb-back){display:flex;align-items:center}:host(.ic-breadcrumb-back) .chevron{display:none}ic-link{--breadcrumb-link-display:inline-flex;--breadcrumb-link-align-items:center;--breadcrumb-link-gap:var(--ic-space-xs)}:host([aria-current=\"page\"]){cursor:text}:host([aria-current=\"page\"]) .current-page-container{display:flex;align-items:center;gap:var(--ic-space-xs);color:var(--ic-breadcrumb-text)}:host([aria-current=\"page\"].ic-breadcrumb-monochrome) .current-page-container{color:var(--ic-breadcrumb-text-monochrome)}:host([aria-current=\"page\"]) slot{pointer-events:none}:host(.collapsed-breadcrumb-wrapper){margin-right:var(--ic-space-xs) !important;display:flex;align-items:center;gap:var(--ic-space-xs)}:host(.collapsed-breadcrumb-wrapper) ::slotted(.collapsed-breadcrumb){border:none;background-color:transparent;color:var(--ic-color-hyperlink-default);text-decoration:underline;font-weight:var(--ic-font-weight-bold);cursor:pointer}:host(.collapsed-breadcrumb-wrapper) ::slotted(.collapsed-breadcrumb:hover),:host(.collapsed-breadcrumb-wrapper) ::slotted(.collapsed-breadcrumb:focus){outline:var(--ic-hc-focus-outline);border-bottom:0.25rem solid !important;margin-bottom:-0.25rem !important;text-decoration:none}.hide,:host(.collapsed-breadcrumb-wrapper) ::slotted(.hide){display:none}.slotted-link-container{gap:var(--ic-space-xs);display:flex}.slotted-link-container .back-icon{width:1.5rem;height:1.5rem}.slotted-link-container .link-wrapper{line-height:1.5rem}@media (forced-colors: active){.back-icon svg{color:currentcolor}}@supports (text-underline-offset: 25%){ic-link{--breadcrumb-link-display:flex}:host(.collapsed-breadcrumb-wrapper) ::slotted(.collapsed-breadcrumb:hover),:host(.collapsed-breadcrumb-wrapper) ::slotted(.collapsed-breadcrumb:focus){text-decoration-line:underline;text-decoration-thickness:25%;text-underline-offset:25%;border-bottom:0 !important;margin-bottom:0 !important}}";
const IcBreadcrumbStyle0 = icBreadcrumbCss;

const Breadcrumb = /*@__PURE__*/ proxyCustomElement(class Breadcrumb extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.HREF_ATTR = "href";
        /**
         * If `true`, aria-current will be set on the breadcrumb.
         */
        this.current = false;
        /**
         * @internal If `true`, the breadcrumb will display as black in the light theme, and white in the dark theme.
         */
        this.monochrome = false;
        /**
         * @internal If `true`, back icon will be displayed.
         */
        this.showBackIcon = false;
        /**
         * @internal Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
        // Prevent focus on breadcrumb if current page and contains slotted link
        this.updatedSlottedLinkFocus = () => {
            // Sets tabindex on wrong element in unit test snapshots
            // - related to known Jest issue: https://github.com/ionic-team/stencil/issues/2830
            if (this.linkSlotContent) {
                this.linkSlotContent.tabIndex = this.current ? -1 : 0; // Prevent focus
            }
            if (this.slottedLinkEl) {
                if (this.current) {
                    this.slottedLinkEl.removeAttribute(this.HREF_ATTR); // Prevent screen reader announcing breadcrumb as a link
                }
                else {
                    this.slottedLinkHref &&
                        this.slottedLinkEl.setAttribute(this.HREF_ATTR, this.slottedLinkHref);
                }
            }
        };
        this.getSlottedLinkEl = () => {
            const link = this.linkSlotContent;
            if (link) {
                const elWithHref = link.hasAttribute(this.HREF_ATTR)
                    ? link
                    : link.querySelector("[href]");
                return elWithHref;
            }
            return null;
        };
        this.renderBackIcon = () => (h("div", { class: "back-icon", innerHTML: backIcon }));
        this.renderDefaultBreadcrumb = (current, pageTitle, describedById, href) => {
            const hasPageTitle = pageTitle !== null && isPropDefined(pageTitle) && pageTitle !== "";
            if (current && hasPageTitle) {
                return (h("span", { class: {
                        "current-page-container": current,
                    } }, isSlotUsed(this.el, "icon") && h("slot", { name: "icon" }), pageTitle));
            }
            return (h("ic-link", { theme: this.theme, monochrome: this.monochrome, href: href, class: "breadcrumb-link", "aria-describedby": this.showBackIcon && describedById && describedById }, this.showBackIcon && this.renderBackIcon(), isSlotUsed(this.el, "icon") && h("slot", { name: "icon" }), pageTitle));
        };
        this.setSlottedCurrentPageClass = () => {
            const icLink = this.el.querySelector("ic-link");
            const currentPage = "current-page";
            if (icLink) {
                icLink.classList.remove(currentPage);
                if (this.current) {
                    const hasCurrentPageClass = icLink.classList.contains(currentPage);
                    if (!hasCurrentPageClass) {
                        icLink.classList.add("breadcrumb-link", currentPage);
                    }
                }
            }
        };
    }
    watchCurrentHandler() {
        this.updatedSlottedLinkFocus();
        this.el.ariaCurrent = this.current ? "page" : null;
    }
    componentDidLoad() {
        var _a, _b;
        const slottedLinkWrapper = (_a = this.el.shadowRoot) === null || _a === void 0 ? void 0 : _a.querySelector(".link-wrapper");
        if (slottedLinkWrapper) {
            const slotEls = getSlotElements(slottedLinkWrapper);
            if (slotEls) {
                this.linkSlotContent = slotEls[0];
            }
            this.slottedLinkEl = this.getSlottedLinkEl();
            this.slottedLinkHref = (_b = this.slottedLinkEl) === null || _b === void 0 ? void 0 : _b.getAttribute("href");
            this.updatedSlottedLinkFocus();
        }
    }
    componentWillRender() {
        this.setSlottedCurrentPageClass();
    }
    /**
     * Sets focus on the breadcrumb.
     */
    async setFocus() {
        var _a, _b;
        (_b = (_a = this.el.shadowRoot) === null || _a === void 0 ? void 0 : _a.querySelector("ic-link")) === null || _b === void 0 ? void 0 : _b.focus();
    }
    render() {
        const { current, href, pageTitle } = this;
        const describedById = `${pageTitle && pageTitle.toLowerCase().replace(" ", "-")}-describedby`;
        const hasPageTitle = pageTitle !== null && isPropDefined(pageTitle) && pageTitle !== "";
        const hasHref = href !== null && isPropDefined(href) && href !== "";
        return (h(Host, { key: '29422d3d1b30d190d6233a644ad70df833478edd', class: {
                "ic-breadcrumb-back": !!this.showBackIcon,
                [`ic-theme-${this.theme}`]: this.theme !== "inherit",
                "ic-breadcrumb-monochrome": !!this.monochrome,
            }, "aria-current": current && "page", role: "listitem" }, h("div", { key: '1f8c4f0fca86a3d08df82674e33cabe7419f7616', class: "breadcrumb" }, h("span", { key: '9761c21d30b9e55e8cf5d3517ada73fa4d73710b', innerHTML: chevronIcon, class: "chevron", "aria-hidden": "true" }), this.showBackIcon && describedById && (h("span", { key: 'ad6be34d684a28dd063895c73f35ed65a3741dc9', id: describedById, class: "hide" }, `Back to ${pageTitle}`)), hasPageTitle && hasHref ? (this.renderDefaultBreadcrumb(!!current, pageTitle, describedById, href)) : (h("div", { class: "slotted-link-container" }, this.showBackIcon && this.renderBackIcon(), h("span", { class: "link-wrapper" }, h("slot", null)))))));
    }
    static get delegatesFocus() { return true; }
    get el() { return this; }
    static get watchers() { return {
        "current": ["watchCurrentHandler"]
    }; }
    static get style() { return IcBreadcrumbStyle0; }
}, [17, "ic-breadcrumb", {
        "current": [4],
        "href": [1],
        "monochrome": [4],
        "pageTitle": [1, "page-title"],
        "showBackIcon": [516, "show-back-icon"],
        "theme": [1],
        "setFocus": [64]
    }, undefined, {
        "current": ["watchCurrentHandler"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ic-breadcrumb", "ic-link"];
    components.forEach(tagName => { switch (tagName) {
        case "ic-breadcrumb":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, Breadcrumb);
            }
            break;
        case "ic-link":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { Breadcrumb as B, defineCustomElement as d };

//# sourceMappingURL=ic-breadcrumb2.js.map