import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { o as onComponentRequiredPropUndefined } from './helpers.js';
import { d as defineCustomElement$6 } from './ic-button2.js';
import { d as defineCustomElement$5 } from './ic-horizontal-scroll2.js';
import { d as defineCustomElement$4 } from './ic-loading-indicator2.js';
import { d as defineCustomElement$3 } from './ic-tooltip2.js';
import { d as defineCustomElement$2 } from './ic-typography2.js';

const icTabGroupCss = ":host{display:block;margin-bottom:var(--ic-space-md);border-bottom:var(--ic-space-1px) solid var(--ic-tab-bottom-border)}:host(.ic-tab-group-monochrome){border-bottom:var(--ic-space-1px) solid\n    var(--ic-tab-bottom-border-monochrome)}:host(.ic-tab-group-inline){margin-bottom:0;border-bottom:none}.tabs-container{display:flex;flex-direction:row}.tabs-container::-webkit-scrollbar{display:none}:host ic-horizontal-scroll{--splitter-color:var(--ic-tab-divider)}:host(.ic-tab-group-monochrome) ic-horizontal-scroll{--splitter-color:var(--ic-tab-divider-monochrome)}";
const IcTabGroupStyle0 = icTabGroupCss;

const TabGroup = /*@__PURE__*/ proxyCustomElement(class TabGroup extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        /**
         * If `true`, the tabs and tab panels will be positioned separately.
         */
        this.inline = false;
        /** @internal Determines whether black variant of the tabs should be displayed. */
        this.monochrome = false;
        /** @internal Determines whether the light or dark variant of the tabs should be displayed. */
        this.theme = "inherit";
    }
    componentDidLoad() {
        onComponentRequiredPropUndefined([{ prop: this.label, propName: "label" }], "Tab Group");
    }
    render() {
        const { inline, theme, label, monochrome } = this;
        return (h(Host, { key: '08da1fef9eb0a16a7f9d0f7cffff3894b3319b09', role: "tablist", "aria-label": label, class: {
                ["ic-tab-group-inline"]: !!inline,
                [`ic-theme-${theme}`]: theme !== "inherit",
                ["ic-tab-group-monochrome"]: !!monochrome,
            } }, h("ic-horizontal-scroll", { key: 'c12cc06aba78c85277b3eab2250c8e61a3b4c4da', theme: theme, "focus-trigger": "tabFocus", monochrome: monochrome }, h("div", { key: '01c299ea10f8600e2e9df303e06c4e97dcdab7c3', class: "tabs-container" }, h("slot", { key: '1f2cb7d4f2f86c7e3ba8f910797a963d15d9a7e0' })))));
    }
    static get delegatesFocus() { return true; }
    static get style() { return IcTabGroupStyle0; }
}, [17, "ic-tab-group", {
        "inline": [516],
        "label": [1],
        "monochrome": [4],
        "theme": [1]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ic-tab-group", "ic-button", "ic-horizontal-scroll", "ic-loading-indicator", "ic-tooltip", "ic-typography"];
    components.forEach(tagName => { switch (tagName) {
        case "ic-tab-group":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TabGroup);
            }
            break;
        case "ic-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "ic-horizontal-scroll":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "ic-loading-indicator":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "ic-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "ic-typography":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const IcTabGroup = TabGroup;
const defineCustomElement = defineCustomElement$1;

export { IcTabGroup, defineCustomElement };

//# sourceMappingURL=ic-tab-group.js.map