import { r as registerInstance, h, H as Host, g as getElement } from './index-a7a720e7.js';
import { b as onComponentRequiredPropUndefined, Y as getInputHelperTextID, Z as getInputValidationTextID, K as IcInformationStatus, _ as warningIcon, $ as errorIcon, T as successIcon } from './helpers-46a2d1fd.js';

const icInputLabelCss = "ic-input-label{margin-bottom:var(--ic-space-xs);--ic-typography-color:var(\n    --ic-input-label-text-color,\n    var(--ic-color-text-primary)\n  )}ic-input-label.with-helper{margin-bottom:var(--ic-space-xxxs)}ic-input-label.ic-input-label-readonly{--ic-typography-color:var(--ic-input-label-readonly-typography-color)}ic-input-label .helpertext{margin-top:var(--ic-space-xxxs);padding-bottom:var(--ic-input-label-helpertext-padding, 0);--ic-typography-color:var(\n    --ic-input-label-helper-text-color,\n    var(--ic-color-text-secondary)\n  )}ic-input-label .helpertext-normal{--ic-typography-color:var(\n    --ic-input-label-helper-text-color,\n    var(--ic-color-text-secondary)\n  )}ic-input-label .helpertext-readonly{--ic-typography-color:var(--ic-input-label-readonly-helpertext-color)}ic-input-label .readonly-label{--ic-typography-color:var(--ic-input-label-readonly-label-color)}ic-input-label .error-label{--ic-typography-color:var(--ic-input-label-error-label-color)}";
const IcInputLabelStyle0 = icInputLabelCss;

const InputLabel = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /**
         * If `true`, the disabled state will be set.
         */
        this.disabled = false;
        /**
         * The helper text that will be displayed.
         */
        this.helperText = "";
        /**
         * The label will be visually hidden.
         */
        this.hideLabel = false;
        /**
         * If `true`, the readonly state will be set.
         */
        this.readonly = false;
        /**
         * If `true`, the input label will require a value.
         */
        this.required = false;
        /**
         * The status of the label - e.g. 'error'.
         */
        this.status = "";
        /**
         * @internal If `true`, wraps label text in label tag
         */
        this.useLabelTag = true;
    }
    componentDidLoad() {
        onComponentRequiredPropUndefined([{ prop: this.label, propName: "label" }], "Input Label");
    }
    render() {
        const { disabled, readonly, label, required, helperText, status, hideLabel, useLabelTag, } = this;
        const labelText = required ? label + " *" : label;
        return (h(Host, { key: '53437d3149f4607c6a4d78d907623cb5007f80d1', class: {
                "ic-input-label-disabled": !!disabled,
                "ic-input-label-readonly": readonly,
                "with-helper": helperText !== "",
            } }, !hideLabel && (h("ic-typography", { key: '454dc75303a9c8a4991d886aea5abe323960a96e', variant: "label", class: {
                "readonly-label": readonly,
                "error-label": status === "error" && !(readonly || disabled),
            } }, readonly || !useLabelTag ? (`${labelText}`) : (h("label", { htmlFor: this.for }, labelText)))), helperText !== "" && (h("ic-typography", { key: '91229fd502726c77cbd35097d78b293461ddefff', variant: "caption", class: {
                helpertext: true,
                "helpertext-normal": !disabled && !readonly,
                "helpertext-readonly": readonly,
            } }, h("span", { key: '56fc1416be966f1af7d2d34d28d450b3fc0def3f', id: this.for && getInputHelperTextID(this.for) }, helperText)))));
    }
};
InputLabel.style = IcInputLabelStyle0;

const icInputValidationCss = "ic-input-validation{width:var(--input-width, 20rem);margin-top:var(--ic-space-xs);display:flex}ic-input-validation.ic-input-validation-full-width{width:100%}ic-input-validation span.status-icon{padding-right:var(--ic-space-xxs)}ic-input-validation span.status-icon>svg{height:1.25rem;width:1.25rem}ic-input-validation span.icon-success>svg{fill:var(--ic-input-validation-success-icon-color)}ic-input-validation span.icon-error>svg{fill:var(--ic-input-validation-error, var(--ic-atoms-status-icon-error))}ic-input-validation span.icon-warning>svg{fill:var(--ic-input-validation-warning-icon-color)}ic-input-validation .statustext{flex-grow:1;color:var(\n    --ic-input-validation-status-text-color,\n    var(--ic-color-text-primary)\n  );--ic-typography-color:var(\n    --ic-input-validation-status-text-color,\n    var(--ic-color-text-primary)\n  )}";
const IcInputValidationStyle0 = icInputValidationCss;

const icon = {
    [IcInformationStatus.Warning]: warningIcon,
    [IcInformationStatus.Error]: errorIcon,
    [IcInformationStatus.Success]: successIcon,
};
const InputValidation = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /**
         *  The ARIA live mode to apply to the message.
         */
        this.ariaLiveMode = "polite";
        /**
         *  If `true`, the input validation will fill the width of the container.
         */
        this.fullWidth = false;
        /**
         * The status of the validation - e.g. 'error' | 'warning' | 'success'.
         */
        this.status = "";
    }
    componentDidLoad() {
        onComponentRequiredPropUndefined([{ prop: this.message, propName: "message" }], "Input Validation");
    }
    render() {
        const { ariaLiveMode, fullWidth, status, message } = this;
        const displayIcon = status !== "" ? icon[status] : "";
        return (h(Host, { key: 'd6af7a655de2bfc6fb1fbe9273d6d9832b77460f', class: {
                [`ic-input-validation-${status}`]: status !== "",
                "ic-input-validation-full-width": !!fullWidth,
            } }, displayIcon !== "" && (h("span", { key: '31756ccbb544bfa04cd4ca92fc074b54c1b1f4bc', class: {
                "status-icon": true,
                [`icon-${status}`]: true,
            }, innerHTML: displayIcon })), h("ic-typography", { key: '5def28291ba379bd93351dcc4ffd89bae149d409', variant: "caption", class: "statustext" }, h("span", { key: '3411302bd27a0b32a03a17b465db0927a018f542', "aria-live": ariaLiveMode, id: this.for && getInputValidationTextID(this.for) }, message)), h("slot", { key: 'a86c22429e48eca2033abddfe4b15c1be5d00e7f', name: "validation-message-adornment" })));
    }
    get el() { return getElement(this); }
};
InputValidation.style = IcInputValidationStyle0;

export { InputLabel as ic_input_label, InputValidation as ic_input_validation };

//# sourceMappingURL=ic-input-label_2.entry.js.map